@@ -3,6 +3,11 @@ from os import path
 
 from featurestore.client import Client
 from featurestore.core.client_config import ClientConfig
+from featurestore.core.collections.classifiers import (
+    EmptyClassifier,
+    RegexClassifier,
+    SampleClassifier,
+)
 from featurestore.core.data_source_wrappers import (
     CSVFile,
     CSVFolder,
@@ -74,4 +79,7 @@ __all__ = [
     "SparkPipeline",
     "DriverlessAIMOJO",
     "JoinFeatureSets",
+    "EmptyClassifier",
+    "RegexClassifier",
+    "SampleClassifier",
 ]
