@@ -4,6 +4,8 @@ from google.protobuf.empty_pb2 import Empty
 
 import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
 
+from ..collections.feature_sets import FeatureSets
+from ..entities.feature_set import FeatureSet
 from ..entities.project import Project
 
 
@@ -17,6 +19,15 @@ class Projects:
         response = self._stub.ListProjects(request)
         return [Project(self._stub, p) for p in response.projects]
 
+    def list_feature_sets(self, project_names=[], filters=None) -> List[FeatureSet]:
+        request = pb.ListFeatureSetsAcrossProjectsRequest()
+        request.project_names.extend(project_names)
+        if filters:
+            query = FeatureSets._build_feature_set_list_query(None, filters)
+            request.query.CopyFrom(query)
+        response = self._stub.ListFeatureSetsAcrossProjects(request)
+        return [FeatureSet(self._stub, fs) for fs in response.feature_sets]
+
     def create(
         self,
         project_name: str,
