@@ -2,14 +2,14 @@ import configparser
 import os
 from urllib.parse import urlparse
 
-from . import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+
 from .user_credentials import (
-    AWSCredentials,
     AzureKeyCredentials,
     AzurePrincipalCredentials,
     AzureSasCredentials,
-    DriverlessAICredentials,
     PostgresCredentials,
+    S3Credentials,
     SnowflakeCredentials,
     TeradataCredentials,
 )
@@ -61,12 +61,6 @@ class CredentialsHelper:
             CredentialsHelper.set_jdbc_credentials(
                 request, source.connection_url, credentials
             )
-        elif isinstance(source, pb.DriverlessAIMOJOSpec):
-            CredentialsHelper.set_driverless_ai_license(request, credentials)
-        elif isinstance(source, pb.SparkPipelineSpec):
-            pass
-        elif isinstance(source, pb.JoinedFeatureSetsSpec):
-            pass
         elif isinstance(source, pb.TempParquetFileSpec):
             pass
         else:
@@ -75,7 +69,7 @@ class CredentialsHelper:
     @staticmethod
     def get_credentials_based_on_cloud(request, url_path, credentials):
         if url_path.lower().startswith("s3"):
-            CredentialsHelper.set_aws_credentials(request, credentials)
+            CredentialsHelper.set_s3_credentials(request, credentials)
         elif url_path.lower().startswith("wasb") or url_path.lower().startswith("abfs"):
             CredentialsHelper.set_azure_credentials(request, url_path, credentials)
         else:
@@ -123,24 +117,35 @@ class CredentialsHelper:
             request.cred.azure.sp_secret = credentials.secret
 
     @staticmethod
-    def set_aws_credentials(request, credentials):
+    def set_s3_credentials(request, credentials):
         if credentials is None:
-            if os.environ.get("AWS_ACCESS_KEY"):
-                access_key = Utils.read_env("AWS_ACCESS_KEY", "S3")
+            if os.environ.get("S3_ACCESS_KEY"):
+                access_key = Utils.read_env("S3_ACCESS_KEY", "S3")
             else:
                 access_key = None
-            if os.environ.get("AWS_SECRET_KEY"):
-                secret_key = Utils.read_env("AWS_SECRET_KEY", "S3")
+            if os.environ.get("S3_SECRET_KEY"):
+                secret_key = Utils.read_env("S3_SECRET_KEY", "S3")
             else:
                 secret_key = None
-            if os.environ.get("AWS_REGION"):
-                region = Utils.read_env("AWS_REGION", "S3")
+            if os.environ.get("S3_REGION"):
+                region = Utils.read_env("S3_REGION", "S3")
             else:
                 region = None
-
-            if all(keys is not None for keys in [access_key, secret_key, region]):
-                credentials = AWSCredentials(access_key, secret_key, region)
-            elif os.path.join(os.path.expanduser("~"), ".aws/credentials"):
+            if os.environ.get("S3_ROLE_ARN"):
+                role_arn = Utils.read_env("S3_ROLE_ARN", "S3")
+            else:
+                role_arn = None
+            if os.environ.get("S3_ENDPOINT"):
+                endpoint = Utils.read_env("S3_ENDPOINT", "S3")
+            else:
+                endpoint = None
+            if region and (role_arn or (access_key and secret_key)):
+                credentials = S3Credentials(
+                    access_key, secret_key, region, endpoint, role_arn
+                )
+            elif os.path.isfile(
+                os.path.join(os.path.expanduser("~"), ".aws/credentials")
+            ):
                 config = configparser.RawConfigParser()
                 config.read(os.path.join(os.path.expanduser("~"), ".aws/credentials"))
                 try:
@@ -152,16 +157,25 @@ class CredentialsHelper:
                 aws_secret = config.get(profile, "aws_secret_access_key")
                 config.read(os.path.join(os.path.expanduser("~"), ".aws/config"))
                 aws_region = config.get("default", "region")
-                credentials = AWSCredentials(
+                credentials = S3Credentials(
                     access_key=aws_key, secret_key=aws_secret, region=aws_region
                 )
             else:
-                raise Exception("Credentials are not of type AWSCredentials!")
-        if not isinstance(credentials, AWSCredentials):
-            raise Exception("Credentials are not of type AWSCredentials!")
+                print(
+                    "Credentials are not provided for AWS. Access only to public data."
+                )
+                request.cred.aws.access_token = "PUBLIC_ONLY"
+                request.cred.aws.secret_token = "PUBLIC_ONLY"
+                return
+        if not isinstance(credentials, S3Credentials):
+            raise Exception("Credentials is not of type S3Credentials!")
         request.cred.aws.access_token = credentials.access_token
         request.cred.aws.secret_token = credentials.secret_token
         request.cred.aws.region = credentials.region
+        if credentials.role_arn:
+            request.cred.aws.role_arn = credentials.role_arn
+        if credentials.endpoint:
+            request.cred.aws.endpoint = credentials.endpoint
 
     @staticmethod
     def set_snowflake_credentials(request, credentials):
@@ -199,15 +213,3 @@ class CredentialsHelper:
             )
         request.cred.jdbc_database.user = credentials.user
         request.cred.jdbc_database.password = credentials.password
-
-    @staticmethod
-    def set_driverless_ai_license(request, credentials):
-        if credentials is None:
-            credentials = DriverlessAICredentials(
-                license_key=Utils.read_env(
-                    "DRIVERLESS_AI_LICENSE_KEY", "Driverless AI MOJO"
-                )
-            )
-        elif not isinstance(credentials, DriverlessAICredentials):
-            raise Exception("Credentials are not of type DriverlessAICredentials!")
-        request.cred.driverless_ai_license = credentials.license_key
