@@ -1,4 +1,4 @@
-from . import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
 
 TINYINT = pb.FeatureDataType.Name(pb.FeatureDataType.TinyInt).upper()
 SMALLINT = pb.FeatureDataType.Name(pb.FeatureDataType.SmallInt).upper()
