@@ -1,17 +1,17 @@
 import json
 import time
 
-from .. import CoreService_pb2 as pb
-from .. import FeatureSetProtoApi_pb2 as FeatureSetApi
-from .. import OnlineApi_pb2 as OnlineApi
-from .. import TimeToLiveApi_pb2 as TimeToLiveApi
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.FeatureSetProtoApi_pb2 as FeatureSetApi
+import ai.h2o.featurestore.api.v1.OnlineApi_pb2 as OnlineApi
+import ai.h2o.featurestore.api.v1.TimeToLiveApi_pb2 as TimeToLiveApi
+
 from .. import interactive_console
 from ..collections.ingest_history import IngestHistory
 from ..credentials import CredentialsHelper
 from ..data_source_wrappers import SparkDataFrame
 from ..entities.feature import Feature
 from ..retrieve_holder import RetrieveHolder
-from ..schema import Schema
 from ..utils import Utils
 from .feature_set_schema import FeatureSetSchema
 from .ingest_job import IngestJob
@@ -31,6 +31,10 @@ class FeatureSet:
         self._feature_set_header.feature_set_id = self._feature_set.id
         self._feature_set_header.feature_set_version = self._feature_set.version
 
+    @property
+    def id(self):
+        return self._feature_set.id
+
     @property
     def project(self):
         return self._feature_set.project
@@ -40,9 +44,13 @@ class FeatureSet:
         return self._feature_set.feature_set_name
 
     @property
-    def version(self):
+    def version(self) -> str:
         return self._feature_set.version
 
+    @property
+    def major_version(self) -> int:
+        return int(self.version.split(".")[0])
+
     @property
     def version_change(self):
         return self._feature_set.version_change
@@ -314,6 +322,9 @@ class FeatureSet:
     def feature_classifiers(self):
         return self._feature_set.feature_classifiers
 
+    def is_derived(self):
+        return self._feature_set.derived_from.HasField("transformation")
+
     @custom_data.setter
     def custom_data(self, value):
         update_request = pb.FeatureSetCustomDataUpdateRequest()
@@ -332,6 +343,8 @@ class FeatureSet:
         request.reason = reason
         if schema:
             request.schema.extend(schema._to_proto_schema())
+            if schema.is_derived():
+                request.derived_from.CopyFrom(schema.derivation._to_proto())
         else:
             request.schema.extend(self.schema.get()._to_proto_schema())
         if affected_features:
@@ -391,7 +404,7 @@ class FeatureSet:
         )
 
     def get_active_jobs(self, job_type=pb.JobType.Unknown):
-        self._get_jobs(True, job_type)
+        return self._get_jobs(True, job_type)
 
     def _get_jobs(self, active, job_type=pb.JobType.Unknown):
         from ..collections.jobs import Jobs  # Lazy import to avoid circular reference
@@ -425,6 +438,8 @@ class FeatureSet:
         end_date_time=None,
         credentials=None,
     ):
+        if self.is_derived():
+            raise Exception("Manual ingest is not allowed on derived feature set")
         from ..data_source_wrappers import get_raw_data_location
 
         if isinstance(source, SparkDataFrame):
@@ -457,11 +472,7 @@ class FeatureSet:
             end_date_time,
             credentials,
         )
-        while not job.is_done():
-            job.show_progress()
-            time.sleep(2)
-        job.show_progress()  # there is possibility that some progress was pushed before finishing job
-        result = job.get_result()
+        result = job.wait_for_result()
         self._feature_set = result._get_feature_set()
         self._feature_set_header.feature_set_version = self._feature_set.version
         return result
@@ -475,15 +486,14 @@ class FeatureSet:
     @interactive_console.record_stats
     def materialize_online(self):
         job = self.materialize_online_async()
-        while not job.is_done():
-            job.show_progress()
-            time.sleep(2)
-
-        job.show_progress()  # there is possibility that some progress was pushed before finishing job
-        result = job.get_result()
-        return result
+        return job.wait_for_result()
 
     def ingest_online(self, rows):
+        if self.is_derived():
+            raise Exception(
+                "Manual ingest online is not allowed on derived feature set"
+            )
+
         if isinstance(rows, list):
             row_list = rows
         else:
