@@ -1,8 +1,8 @@
 import time
 
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
 from featurestore.core import interactive_console
 
-from .. import CoreService_pb2 as pb
 from ..retrieve_holder import RetrieveHolder
 from ..utils import Utils
 from .revert_ingest_job import RevertIngestJob
@@ -22,13 +22,12 @@ class Ingest:
     @interactive_console.record_stats
     def revert(self):
         job = self.revert_async()
-        while not job.is_done():
-            job.show_progress()
-            time.sleep(2)
-        job.show_progress()  # there is possibility that some progress was pushed before finishing job
-        return job.get_result()
+        return job.wait_for_result()
 
     def revert_async(self) -> RevertIngestJob:
+        if self._feature_set.derived_from.HasField("transformation"):
+            raise Exception("Manual revert is not allowed on derived feature set")
+
         request = pb.StartRevertIngestJobRequest()
         request.feature_set.CopyFrom(self._feature_set)
         request.ingest_id = self._ingest.ingest_id
