@@ -1,6 +1,7 @@
 import json
 
-from .. import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+
 from ..retrieve_holder import RetrieveAsLinksCommon
 from .base_job import BaseJob
 
