@@ -1,4 +1,4 @@
-from ..base import ArrayField, NumericField, StringField
+from ..base import NumericField, StringField
 
 
 class FeatureProfile(object):
@@ -6,8 +6,8 @@ class FeatureProfile(object):
 
 
 class Feature(object):
-    name = StringField("features.name")
+    name = StringField("features.fullyQualifiedFeatureNames")
     description = StringField("features.description")
     importance = NumericField("features.importance")
-    data_type = ArrayField("features.dataTypeHierarchicalPaths")
+    data_type = StringField("features.dataType")
     profile = FeatureProfile
