@@ -8,8 +8,6 @@ from typing import *
 
 import grpc
 
-import featurestore
-
 from .auth import AuthException
 
 
@@ -30,9 +28,9 @@ class AuthClientInterceptor(
 
     def _intercept_call(self, continuation, client_call_details, request_or_iterator):
         if client_call_details.method in (
-            "/featurestore.core.CoreService/Login",
-            "/featurestore.core.CoreService/GetAccessToken",
-            "/featurestore.core.CoreService/GetVersion",
+            "/ai.h2o.featurestore.api.v1.CoreService/Login",
+            "/ai.h2o.featurestore.api.v1.CoreService/GetAccessToken",
+            "/ai.h2o.featurestore.api.v1.CoreService/GetVersion",
         ):
             return continuation(client_call_details, request_or_iterator)
         else:
@@ -52,7 +50,6 @@ class AuthClientInterceptor(
                 sys.tracebacklimit = 0
                 raise AuthException(token_or_error)
             metadata.append(("request-id", str(uuid.uuid4())))
-            metadata.append(("client-version", featurestore.__version__))
             new_client_call_details = _ClientCallDetails(
                 client_call_details.method,
                 self._client._client_config.timeout,
