@@ -1,8 +1,7 @@
-import featurestore.core.CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
 
 from . import interactive_console
 from .config import ConfigUtils
-from .utils import Utils
 
 
 class JobInfo:
