@@ -18,11 +18,15 @@ class AzurePrincipalCredentials:
         self.secret = secret
 
 
-class AWSCredentials:
-    def __init__(self, access_key, secret_key, region):
+class S3Credentials:
+    def __init__(
+        self, access_key, secret_key, region=None, endpoint=None, role_arn=None
+    ):
         self.access_token = access_key
         self.secret_token = secret_key
         self.region = region
+        self.role_arn = role_arn
+        self.endpoint = endpoint
 
 
 class SnowflakeCredentials:
@@ -37,11 +41,6 @@ class TeradataCredentials:
         self.password = password
 
 
-class DriverlessAICredentials:
-    def __init__(self, license_key):
-        self.license_key = license_key
-
-
 class PostgresCredentials:
     def __init__(self, user, password):
         self.user = user
