@@ -15,6 +15,17 @@ class Utils:
         else:
             return None
 
+    @staticmethod
+    def is_running_on_databricks() -> bool:
+        try:
+            from pyspark.sql import SparkSession
+
+            spark = SparkSession.getActiveSession()
+            spark.conf.get("spark.databricks.clusterUsageTags.sparkVersion")
+            return True
+        except:
+            return False
+
     @staticmethod
     def read_env(variable_name, source):
         value = os.environ.get(variable_name)
